#!/usr/bin/env xpyv

#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#------------------------------------------------------------------------------------------------- 

import sys
import logging
from os.path import normpath, realpath, join
from xpyv import project_root_path

def get_libpath():
    return join(normpath(project_root_path.find(realpath(__file__))), 'lib')

def set_pythonpath():
    libpath = get_libpath()
    sys.path.append(libpath)

set_pythonpath()

from hostattachment_project import initialize_project
initialize_project()

from xiv_diag.scripts.logger import set_logging

from xiv_xsf.host import storage
from xiv_xsf.scsy.device import Device
from xiv_xsf.scsy.commands import Inquiry

INQUIRY_PAGES = ['evpd00', 'evpd80', 'evpd83']

def get_supported_pages_from_page00(device):
    try:
        return device.inquiry.evpd00()
    except Exception, e:
        logging.error('exception has been raised: %s' % str(e))
        return []

def log_predefined_page(device, filename, page):
    logging.info('pre-defined page %s for device %s:' % (page, filename))
    try:
        logging.info(getattr(device.inquiry, page)())
    except Exception, e:
        logging.error('exception has been raised: %s' % str(e))
    
def log_raw_page(device, filename, page):
    try:
        logging.info('raw page %s for device %s' % (hex(page), filename))
        inquiry = Inquiry()
        command = inquiry.getCommand(evpd=True, page_code=page)
        logging.info('%r' % inquiry.extended(device._raw_device, command, auto_correct=True, trim=True, raw=True))
    except Exception, e:
        logging.info('exception has been raised: %s' % str(e))
    
def log_inquiry_data_of_device(filename):
    device = Device()
    logging.info('opening device %s' % filename)
    device.open(filename)
    for page in INQUIRY_PAGES:
        log_predefined_page(device, filename, page)
    for page in get_supported_pages_from_page00(device):
        log_raw_page(device, filename, page)
    device.close()

def log_all_inquiry_data():
    device = Device()
    devices = []
    try:
        devices = storage.get_all_storage_devices()
    except Exception, e:
        logging.error('exception has been raised: %s' % str(e))
    for item in devices:
        try:
            log_inquiry_data_of_device(item.device.raw_device_filename)
        except Exception ,e:
            logging.error('exception has been raised: %s' % str(e))

def main():
    set_logging("inquiry")
    log_all_inquiry_data()

main()

